import type { BuiltinSimulatorRenderer } from '@alilc/lowcode-designer';
import type { Component } from 'vue';
import type { ComponentPublicInstance } from 'vue';
import type { ComponentSchema } from '@alilc/lowcode-types';
import type { Config } from '@cdlab996/lowcode-vue-renderer2.7';
import type { DocumentModel } from '@alilc/lowcode-designer';
import type { I18nMessages } from '@cdlab996/lowcode-vue-renderer2.7';
import type { Node as Node_2 } from '@alilc/lowcode-designer';
import type { NpmInfo } from '@alilc/lowcode-types';
import type { RootSchema } from '@alilc/lowcode-types';
import type Router from 'vue-router';
import { default as Vue_2 } from 'vue';
import { default as VueRenderer } from '@cdlab996/lowcode-vue-renderer2.7';
import { config as vueRendererConfig } from '@cdlab996/lowcode-vue-renderer2.7';

export declare type ComponentInstance = ComponentPublicInstance;

declare const _default: VueSimulatorRenderer;
export default _default;

export declare interface DocumentInstance {
    readonly id: string;
    readonly key: string;
    readonly path: string;
    readonly scope: Record<string, unknown>;
    readonly document: DocumentModel;
    readonly instancesMap: Map<string, ComponentInstance[]>;
    readonly schema: RootSchema;
    readonly messages: I18nMessages;
    getComponentInstance(id: number): ComponentInstance | null;
    mountInstance(id: string, instance: ComponentInstance): (() => void) | void;
    unmountIntance(id: string, instance: ComponentInstance): void;
    rerender(): void;
    getNode(id: string): Node_2 | null;
}

export declare type MinxedComponent = NpmInfo | Component | ComponentSchema;

export declare interface SimulatorViewLayout {
    Component?: Component;
    componentName?: string;
    props?: Record<string, unknown>;
}

export { VueRenderer }

export { vueRendererConfig }

export declare interface VueSimulatorRenderer extends BuiltinSimulatorRenderer {
    app: Vue_2;
    config: Config;
    router: Router;
    layout: SimulatorViewLayout;
    device: string;
    locale: string;
    designMode: 'design';
    libraryMap: Record<string, string>;
    components: Record<string, Component>;
    autoRender: boolean;
    componentsMap: Record<string, MinxedComponent>;
    documentInstances: DocumentInstance[];
    requestHandlersMap: Record<string, CallableFunction>;
    dispose(): void;
    rerender(): void;
    getCurrentDocument(): DocumentInstance | undefined;
}


export * from "@cdlab996/lowcode-vue-renderer2.7";

export { }
